@@ -2,7 +2,7 @@ package App::Yath::Command::failed;
 use strict;
 use warnings;
 
-our $VERSION = '1.000021'; # TRIAL
+our $VERSION = '1.000022'; # TRIAL
 
 use Test2::Util::Table qw/table/;
 use Test2::Harness::Util::File::JSONL;
@@ -86,7 +86,7 @@ sub run {
 
     print "\nThe following jobs failed at least once:\n";
     print join "\n" => table(
-        header => ['Job ID', 'Times Run', 'Test File', "Succeded Eventually?"],
+        header => ['Job ID', 'Times Run', 'Test File', "Succeeded Eventually?"],
         rows   => $rows,
     );
     print "\n";
