@@ -2,7 +2,7 @@ package Test2::Harness::Runner::Job;
 use strict;
 use warnings;
 
-our $VERSION = '1.000021'; # TRIAL
+our $VERSION = '1.000022'; # TRIAL
 
 use Carp qw/confess croak/;
 use Config qw/%Config/;
@@ -13,7 +13,7 @@ use Time::HiRes qw/time/;
 use File::Spec();
 use File::Temp();
 
-use Test2::Harness::Util qw/fqmod clean_path write_file_atomic write_file mod2file open_file parse_exit process_includes/;
+use Test2::Harness::Util qw/fqmod clean_path write_file_atomic write_file mod2file open_file parse_exit process_includes chmod_tmp/;
 use Test2::Harness::IPC;
 
 use parent 'Test2::Harness::IPC::Process';
@@ -310,7 +310,7 @@ sub job_dir {
 
     my $job_dir = File::Spec->catdir($self->run_dir, $self->{+TASK}->{job_id} . '+' . $self->is_try);
     mkdir($job_dir) or die "$$ $0 Could not create job directory '$job_dir': $!";
-    chmod(1777, $job_dir) or warn "Could not chmod job dir: $!\n";
+    chmod_tmp($job_dir);
     $self->{+JOB_DIR} = $job_dir;
 }
 
@@ -320,7 +320,7 @@ sub tmp_dir {
     return $self->{+TMP_DIR} if $self->{+TMP_DIR};
 
     my $tmp_dir = File::Temp::tempdir("XXXXXX", DIR => $self->runner->tmp_dir);
-    chmod(1777, $tmp_dir) or warn "Could not chmod temp dir: $!\n";
+    chmod_tmp($tmp_dir);
 
     $self->{+TMP_DIR} = clean_path($tmp_dir);
 }
@@ -468,6 +468,7 @@ sub env_vars {
         TMPDIR              => $self->tmp_dir,
         TEMPDIR             => $self->tmp_dir,
         SYSTEM_TMPDIR       => $self->{+SETTINGS}->harness->orig_tmp,
+        SYSTEM_TMPDIR_PERMS => $self->{+SETTINGS}->harness->orig_tmp_perms,
 
         HARNESS_IS_VERBOSE    => $verbose,
         T2_HARNESS_IS_VERBOSE => $verbose,
